@@ -62,30 +62,6 @@ distinct_columns.default <- function(x, table = names(x), ...) {
   sort(unique(unlist(all_names, use.names = FALSE)))
 }
 
-#' @rdname distinct_params
-#' @export
-unique_params <- function(x, table = "data") {
-  distinct_params(x, table = table)
-}
-
-#' @rdname distinct_params
-#' @export
-unique_locations <- function(x, table = "data") {
-  distinct_locations(x, table = table)
-}
-
-#' @rdname distinct_params
-#' @export
-unique_datasets <- function(x, table = "data") {
-  distinct_datasets(x, table = table)
-}
-
-#' @rdname distinct_params
-#' @export
-unique_columns <- function(x, table = names(x)) {
-  distinct_columns(x, table = table)
-}
-
 #' @rdname distinct_params
 #' @importFrom dplyr src_tbls
 #' @export
@@ -233,7 +209,8 @@ update_datasets.default <- function(x, datasets, ...) {
   if(any(rows)) {
     .update_rows(x, "datasets", rows, ...)
   } else {
-    stop("Zero rows were found for dataset: ", paste(datasets, collapse = ", "))
+    bad_datasets <- paste0("'", datasets, "'", collapse = ", ")
+    abort(glue::glue("Zero rows were found for dataset {bad_datasets}"))
   }
 }
 
@@ -257,11 +234,9 @@ update_locations.default <- function(x, locations, datasets, ...) {
   if(any(rows)) {
     .update_rows(x, "locations", rows, ...)
   } else {
-    stop("Zero rows were found for locations: ", 
-         paste(locations, collapse = ", "),
-         " (datasets: ", 
-         paste(datasets, collapse = ", "),
-         ")")
+    bad_locations <- paste0("'", locations, "'", collapse = ", ")
+    bad_datasets <- paste0("'", datasets, "'", collapse = ", ")
+    abort(glue::glue("Zero rows were found for locations {bad_locations} (datasets: {bad_datasets})"))
   }
 }
 
@@ -285,11 +260,9 @@ update_params.default <- function(x, params, datasets, ...) {
   if(any(rows)) {
     .update_rows(x, "params", rows, ...)
   } else {
-    stop("Zero rows were found for params: ", 
-         paste(params, collapse = ", "),
-         " (datasets: ", 
-         paste(datasets, collapse = ", "),
-         ")")
+    bad_params <- paste0("'", params, "'", collapse = ", ")
+    bad_datasets <- paste0("'", datasets, "'", collapse = ", ")
+    abort(glue::glue("Zero rows were found for params {bad_params} (datasets: {bad_datasets})"))
   }
 }
 
@@ -320,22 +293,29 @@ update_columns.default <- function(x, columns, tables, datasets, ...) {
   if(any(rows)) {
     .update_rows(x, "columns", rows, ...)
   } else {
-    stop("Zero rows were found for columns: ", 
-         paste(columns, collapse = ", "),
-         " (datasets: ", 
-         paste(datasets, collapse = ", "),
-         "; tables: ",
-         paste(tables, collapse = ", "),
-         ")")
+    bad_columns <- paste0("'", columns, "'", collapse = ", ")
+    bad_datasets <- paste0("'", datasets, "'", collapse = ", ")
+    bad_tables <- paste0("'", tables, "'", collapse = ", ")
+    abort(
+      glue::glue(
+        "Zero rows were found for columns {bad_columns} (datasets: {bad_datasets}; tables: {bad_tables})"
+      )
+    )
   }
 }
 
 .update_rows <- function(x, tbl, rows, ...) {
   # assign vals, check that it is one row
   vals <- tibble::tibble(...)
-  # no rows mean there is nothign to update
-  if(nrow(vals) == 0) return(x)
-  if(nrow(vals) != 1) stop("values to update must all be of length 1")
+  # no rows mean there is nothing to update
+  # this gets handled by wrapper functions
+  if(nrow(vals) == 0) {
+    return(x) # nocov
+  }
+  
+  if(nrow(vals) != 1) {
+    abort("values to update must all be of length 1")
+  }
   
   # bind vals to end of table with dummy dataset, to ensure types are correct
   # and all columns exist
