@@ -97,7 +97,7 @@ subset.mudata <- function(x, ..., datasets = NULL, params = NULL,
 #'   or [matches][dplyr::matches].
 #' @param .factor If TRUE, the new object will keep the order specified by converting
 #'   columns to factors. This may be useful for specifying order when using
-#'   [autoplot.mudata].
+#'   ggplot2.
 #'
 #' @seealso
 #' [select][dplyr::select], [rename_locations], [distinct_locations], 
@@ -258,7 +258,6 @@ filter_datasets.default <- function(.data, ...) {
   datasets <- .data$datasets %>%
     dplyr::filter(!!!filter_args) %>%
     dplyr::distinct(.data$dataset) %>%
-    dplyr::collect() %>%
     dplyr::pull("dataset")
   filter_data(.data, .data$dataset %in% datasets)
 }
